import axios from "axios";
import { Message, MessageBox } from "element-ui";

// 创建axios实例
const service = axios.create({
  baseURL: process.env.DEVELOP, // api 的 base_url
  timeout: 5000 // 请求超时时间
});

// request拦截器
service.interceptors.request.use(
  config => {
    if (localStorage.getItem("token")) {
      config.headers["token"] = localStorage.getItem("token"); // 让每个请求携带自定义token 请根据实际情况自行修改
    }
    return config;
  },
  error => {
    // Do something with request error
    console.log(error); // for debug
    Promise.reject(error);
  }
);

// response 拦截器
service.interceptors.response.use(
  response => {
    /**
     * code为非200是抛错 可结合自己业务进行修改
     */
    const res = response.data;
    if (res.code !== 200) {
      Message({
        message: res.message,
        type: "error",
        duration: 5 * 1000
      });
    } else {
      return response.data;
    }
  },
  error => {
    console.log("err" + error); // for debug
    Message({
      message: error.message,
      type: "error",
      duration: 5 * 1000
    });
    return Promise.reject(error);
  }
);

// 获取三级渠道列表
export function getCascaderChannel(params) {
  return service({
    url: "/statistics/channel/list",
    method: "get",
    params
  });
}
// 获取分销人员列表
export function getSaleUser(params) {
  console.log(process.env.NODE_ENV);
  return service({
    url:
      process.env.NODE_ENV == "production"
        ? "http://reader-api.efunbox.cn/cms" + "/sale/user"
        : "http://resources.ai160.com/cms" + "/sale/user",
    method: "get",
    params
  });
}
// 获取渠道数据
export function getChannelData(params) {
  return service({
    url: "/statistics/develop/list",
    method: "get",
    params
  });
}
// 获取数据统计
export function getTotalData(params) {
  return service({
    url: "/statistics/develop/summary",
    method: "get",
    params
  });
}
// 获取数据统计2
export function getTotalData2(params) {
  return service({
    url: "/statistics/develop/summary1",
    method: "get",
    params
  });
}
